@@ -51,7 +51,7 @@ class CodeArtifact(
         '''
         props = CodeArtifactProps(repository=repository, bucket=bucket)
 
-        jsii.create(CodeArtifact, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
@@ -331,7 +331,7 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
         '''
         props = NpmJsProps(staging_bucket=staging_bucket)
 
-        jsii.create(NpmJs, self, [props])
+        jsii.create(self.__class__, self, [props])
 
     @jsii.member(jsii_name="bind")
     def bind(
